2022-09-29 Version: 1.0.5
- Automatically generate sdk tasks.

2022-08-02 Version: 1.0.4
- The input parameter IpProtection of UpdateIpProtection API  is corrected to be required. 

2022-05-20 Version: 1.0.3
- Ip related APIs are changed to visiable and QPM is set as 60 .

2022-04-21 Version: 1.0.2
- Some APIs are changed to invisiable.
- Wrong type of SenderStatisticsDetailByParam reponse fields is fixed.

2022-04-13 Version: 1.0.1
- Some APIs are changed to invisiable.
- Wrong type of QueryInvalidAddress reponse fields is fixed.

2020-12-30 Version: 1.0.0
- AMP Version Change.

